## Overview
All servers (physical and virtual) are documented within this specific page.  They are written in a specific annotated manner in order to make them copy/paste ready for the Ansible AWX Operator server that interacts with devices in the homelab over `SSH` and `WinRM` protocols.  This allows me to automate functions such as updates across the entire homelab declaratively versus individually.

**Note**: This list does not include container-based workloads.  Those can be found within the [Container Network IP Table](https://docs.bunny-lab.io/Networking/IP%20Tables/192.168.5.0%20-%20Container%20Network/) document.  Given that Ansible does not interact with containers in my homelab (*yet*), these devices are not listed within this document.

## Updating Ansible Inventory
Whenever changes are made here, they need to be replicated to the production [Ansible AWX Inventory File](https://git.bunny-lab.io/GitOps/awx.bunny-lab.io/_edit/main/inventories/homelab.ini).  This ensures that Ansible AWX is always up-to-date.  Simply copy/paste the codeblock below into the linked inventory file, and commit the change with a comment explaining what was added/removed from the inventory list.

```ini title="https://git.bunny-lab.io/GitOps/awx.bunny-lab.io/src/branch/main/inventories/homelab.ini"
# ----------------------------------------------------------------- #
# Servers (Physical and Virtual) - Hosts Mapped to IPs / FQDNs      #
# ----------------------------------------------------------------- #
# Deep Nodes
deep-node ansible_host=10.0.0.20

lab-pfsense-01 ansible_host=192.168.3.1 # (1)
lab-jelly-01 ansible_host=lab-jelly-01.bunny-lab.io # (2)
moon-storage-01 ansible_host=192.168.3.3 # (3)
virt-node-01 ansible_host=virt-node-01.bunny-lab.io # (4)
bunny-node-02 ansible_host=bunny-node-02.bunny-lab.io # (5)
lab-games-04 ansible_host=lab-games-04.bunny-lab.io # (6)
lab-photos-01 ansible_host=lab-photos-01.bunny-lab.io # (7)
# NOT-IN-USE ansible_host=NOT-IN-USE.bunny-lab.io # (8)
# NOT-IN-USE ansible_host=NOT-IN-USE.bunny-lab.io # (9)
lab-ansible-01 ansible_host=lab-ansible-01.bunny-lab.io # (10)
lab-games-02 ansible_host=lab-games-02.bunny-lab.io # (11)
lab-ferrumgate-01 ansible_host=lab-ferrumgate-01.bunny-lab.io # (12)
mail ansible_host=mail.bunny-lab.io # (13)
lab-games-03 ansible_host=lab-games-03.bunny-lab.io # (14)
lab-docker-01 ansible_host=lab-docker-01.bunny-lab.io # (15)
lab-games-05 ansible_host=lab-games-05.bunny-lab.io # (16)
# NOT-IN-USE ansible_host=NOT-IN-USE.bunny-lab.io @ (17)
lab-auth-01 ansible_host=lab-auth-01.bunny-lab.io # (18)
container-node-01 ansible_host=container-node-01.bunny-lab.io # (19)
lab-auth-02 ansible_host=lab-auth-02.bunny-lab.io # (20)
lab-puppet-01 ansible_host=lab-puppet-01.bunny-lab.io # (21)
# NOT-IN-USE ansible_host=NOT-IN-USE.bunny-lab.io # (22)
usagi-cluster ansible_host=usagi-cluster.bunny-lab.io # (23)
lab-pool-01 ansible_host=lab-pool-01.bunny-lab.io # (24)
lab-dc-01 ansible_host=lab-dc-01.bunny-lab.io # (25)
lab-dc-02 ansible_host=lab-dc-02.bunny-lab.io # (26)
lab-iris-01 ansible_host=lab-iris-01.bunny-lab.io # (27)
lab-games-01 ansible_host=lab-games-01.bunny-lab.io # (28)
lab-cloud-01 ansible_host=lab-cloud-01.bunny-lab.io # (29)
lab-dt-01 ansible_host=lab-dt-01.bunny-lab.io # (30)
lab-dt-02 ansible_host=lab-dt-02.bunny-lab.io # (31)
lab-matrix-01 ansible_host=lab-matrix-01.bunny-lab.io # (32)
lab-draas-01 ansible_host=lab-draas-01.bunny-lab.io # (33)
lab-draas-01-ilo ansible_host=192.168.3.34 # (34)
deeplab-dc-01 ansible_host=deeplab-dc-01.deeptree-lab.io # (35)
deeplab-node-01 ansible_host=deeplab-node-01.deeptree-lab.io # (36)
lab-onion-01 ansible_host=192.168.3.37 # (37)
lab-wazuh-01 ansible_host=192.168.3.38 # (38)

# ----------------------------------------------------------------- #
# Host Groups - Various Logical Groupings of Devices                #
# ----------------------------------------------------------------- #
[domainControllers]
lab-dc-01
lab-dc-02

[windowsServers]
virt-node-01
bunny-node-02
lab-games-04
lab-games-02
lab-games-03
lab-games-05
lab-dc-01
lab-dc-02
lab-iris-01
lab-games-01
lab-dt-02
lab-draas-01

[linuxServers]
#lab-jelly-01
#moon-storage-01
lab-photos-01
#lab-ferrumgate-01
mail
lab-docker-01
lab-auth-01
container-node-01
lab-auth-02
lab-puppet-01
#lab-pool-01
lab-cloud-01
lab-dt-01
#lab-matrix-01
#lab-onion-01
lab-wazuh-01

# ----------------------------------------------------------------- #
# Host Groups - Variables Defining Specific Requirements of Groups  #
# ----------------------------------------------------------------- #
[domainControllers:vars]
ansible_connection=winrm
ansible_port=5986
ansible_winrm_transport=kerberos
ansible_winrm_scheme=https
ansible_winrm_server_cert_validation=ignore

[windowsServers:vars]
ansible_connection=winrm
ansible_port=5986
ansible_winrm_transport=kerberos
ansible_winrm_scheme=https
ansible_winrm_server_cert_validation=ignore

[linuxServers:vars]
ansible_connection=ssh
```

1.  pfSense Firewall @ `192.168.3.1` | [Deployment Instructions](https://example.com)
2.  Jellyfin Media Server @ `192.168.3.2`
3.  TrueNAS Core Server @ `192.168.3.3`
4.  Hyper-V Virtualization Node @ `192.168.3.4`
5.  Hyper-V Virtualization Node @ `192.168.3.5`
6.  Satisfactory Dedicated Server @ `192.168.3.6`
7.  Immich Server @ `192.168.3.7`
8.  Not Currently In-Use @ `192.168.3.8`
9.  Not Currently In-Use @ `192.168.3.9`
10.  Ansible AWX @ `192.168.3.10`
11.  Minecraft - All The Mods 9 @ `192.168.3.11`
12.  Ferrumgate Server @ `192.168.3.12`
13.  Self-Hosted iRedMail Email Server @ `192.168.3.13`
14.  Minecraft - All The Mods 10 @ `192.168.3.14`
15.  Docker Container Environment @ `192.168.3.15`
16.  Valheim Server @ `192.168.3.16`
17.  Not Currently In-Use @ `192.168.3.17`
18.  Keycloak Server @ `192.168.3.18`
19.  Portainer @ `192.168.3.19`
20.  PrivacyIDEA @ `192.168.3.20`
21.  Puppet Server @ `192.168.3.21`
22.  Not Currently In-Use @ `192.168.3.22`
23.  Hyper-V Failover Cluster @ `192.168.3.23`
24.  TrueNAS SCALE @ `192.168.3.24`
25.  Primary Domain Controller @ `192.168.3.25`
26.  Secondary Domain Controller @ `192.168.3.26`
27.  Blue Iris Surveillance @ `192.168.3.27`
28.  ARK: Survival Ascended Server @ `192.168.3.28`
29.  Nextcloud AIO @ `192.168.3.29`
30.  Rocky Linux 9.3 Work VM @ `192.168.3.30`
31.  Windows 11 Work VM @ `192.168.3.31`
32.  Matrix Synapse HomeServer @ `192.168.3.32`
33.  Dedicated Veeam Backup Server @ `192.168.3.33`
34.  LAB-DRAAS-01 iLO IPMI Access Interface @ `192.168.3.34`
35.  Deep Lab Domain Controller @ `192.168.3.35`
36.  Deep Lab Endpoint Workstation @ `192.168.3.36`
37.  Security Onion @ `192.168.3.37`
38.  Wazuh SIEM Security VM @ `192.168.3.38`